import React from "react";
import PropTypes from "prop-types";
import { Grid } from "@material-ui/core";
import { makeStyles, withStyles } from "@material-ui/core/styles";
import Checkbox from "@material-ui/core/Checkbox";
import { blue } from "@material-ui/core/colors";

const GreenCheckbox = withStyles({
  root: {
    color: blue[400],
    "&$checked": {
      color: blue[600]
    }
  },
  checked: {}
})((props) => <Checkbox color="default" {...props} />);

const useStyles = makeStyles((theme) => ({
  value: {
    fontWeight: theme.typography.fontWeightMedium
  },
  miniContainer: {
    paddingTop: "10px"
  }
}));

const SessionSummary = ({ session }) => {
  const classes = useStyles();

  return (
    <>
      <Grid container className={classes.miniContainer}>
        <Grid item xs={12} sm={3} md={3}>
          {"Session: "}
          <span className={classes.value}>{session.sessionId}</span>
        </Grid>
        <Grid item xs={12} sm={3} md={3}>
          {"Active: "}
          {session.active ? (
            <GreenCheckbox checked={true} disabled />
          ) : (
            <Checkbox indeterminate disabled />
          )}
        </Grid>
        <Grid item xs={12} sm={3} md={3}>
          {"Start date: "}
          <span className={classes.value}>{session.startDate}</span>
        </Grid>
      </Grid>
    </>
  );
};

SessionSummary.propTypes = {
  session: PropTypes.object.isRequired
};

export default SessionSummary;
